# Reference

API documentation generated from the source code with mkdocstrings. For architectural explanations of how the SDK is built and how the container-first workflow execution model works, see the [Explanation](../explanation/index.md) section.

## In this section

- [API Reference](api/index.md)
